@php
    use Illuminate\Support\Facades\Route;
@endphp
<!DOCTYPE html>
<html lang="{{ session()->get('locale') ?? app()->getLocale() }}"
    data-assets-path="{{ asset('/assets') . '/' }}"
    data-base-url="{{ url('/') }}"
    data-route="{{ Route::currentRouteName() }}">
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">

    <title>@hasSection('title') @yield('title') | @endif{{ $_web['title'] }}</title>

    <meta name="description" content="{{ $_web['description'] }}" />
    <meta name="author" content="{{ config('_var.author') }}">

    <!-- laravel CRUD token -->
    <meta name="csrf-token" content="{{ csrf_token() }}">

    <!-- Favicons-->
    <link rel="icon" href="{{ asset('storage/' . $_web['favicon']['16x16']) }}" type="image/x-icon">
    <link rel="icon" sizes="192x192" href="{{ asset('storage/' . $_web['favicon']['192x192']) }}">
    <link rel="apple-touch-icon" type="image/x-icon" sizes="76x76" href="{{ asset('storage/' . $_web['favicon']['76x76']) }}">
    <link rel="apple-touch-icon" type="image/x-icon" sizes="120x120" href="{{ asset('storage/' . $_web['favicon']['120x120']) }}">
    <link rel="apple-touch-icon" type="image/x-icon" sizes="152x152" href="{{ asset('storage/' . $_web['favicon']['152x152']) }}">
    <link rel="apple-touch-icon" type="image/x-icon" sizes="180x180" href="{{ asset('storage/' . $_web['favicon']['180x180']) }}">

    <script src="https://cdn.tailwindcss.com"></script>

    <!-- Mobile Metas -->
    <meta name="viewport" content="width=device-width, initial-scale=1, minimum-scale=1.0, shrink-to-fit=no">
</head>
<body class="bg-gray-50 text-gray-800">
    <!-- Header -->
    <header class="bg-white shadow">
        <div class="container mx-auto px-4 py-4 flex justify-between items-center">
            <a href="/" class="text-2xl font-bold text-blue-600">
                <img src="{{ asset('storage/' . $_web['image_logo']['small']) }}" style="width: 50px;" class="inline-block" alt="{{ $_web['app_name'] }}" />
                {{ $_web['app_name'] }}
            </a>
            <nav class="hidden md:flex space-x-6">
                <a href="#features" class="hover:text-blue-600">Características</a>
                <a href="#about" class="hover:text-blue-600">Sobre Nosotros</a>
                <a href="#contact" class="hover:text-blue-600">Contacto</a>
            </nav>
            <a href="/login" class="hidden md:block px-4 py-2 bg-blue-600 text-white rounded hover:bg-blue-500">Ingresar</a>
            <button class="md:hidden text-gray-600 focus:outline-none" id="menu-btn">
                <svg xmlns="http://www.w3.org/2000/svg" class="h-6 w-6" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                    <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M4 6h16M4 12h16m-7 6h7" />
                </svg>
            </button>
        </div>
        <nav class="md:hidden bg-white shadow hidden" id="menu">
            <a href="#features" class="block px-4 py-2 hover:bg-gray-100">Características</a>
            <a href="#about" class="block px-4 py-2 hover:bg-gray-100">Sobre Nosotros</a>
            <a href="#contact" class="block px-4 py-2 hover:bg-gray-100">Contacto</a>
            <a href="/login" class="block px-4 py-2 bg-blue-600 text-white text-center hover:bg-blue-500">Ingresar</a>
        </nav>
    </header>

    <!-- Hero Section -->
    <section class="bg-blue-600 text-white">
        <div class="container mx-auto px-4 py-16 text-center">
            <h1 class="text-4xl font-bold mb-4">Bienvenido a {{ $_web['title'] }}</h1>
            <p class="text-lg mb-6">El mejor administrador para negocios en México, optimizado con los catálogos SAT y herramientas avanzadas.</p>
            <a href="/login" class="px-6 py-3 bg-white text-blue-600 rounded shadow hover:bg-gray-100">Empezar ahora</a>
        </div>
    </section>

    <pre>
        @php
            print_r($_web);
        @endphp
    </pre>

    <!-- Features -->
    <section id="features" class="py-16">
        <div class="container mx-auto px-4">
            <h2 class="text-3xl font-bold text-center mb-8">Características</h2>
            <div class="grid grid-cols-1 md:grid-cols-3 gap-8">
                <div class="bg-white shadow p-6 rounded">
                    <h3 class="text-xl font-bold mb-2">Optimización SAT</h3>
                    <p class="text-gray-600">Automatiza y gestiona tus procesos fiscales con los catálogos CFDI 4.0.</p>
                </div>
                <div class="bg-white shadow p-6 rounded">
                    <h3 class="text-xl font-bold mb-2">Interfaz moderna</h3>
                    <p class="text-gray-600">Diseño limpio y responsivo con tecnología de última generación.</p>
                </div>
                <div class="bg-white shadow p-6 rounded">
                    <h3 class="text-xl font-bold mb-2">Herramientas avanzadas</h3>
                    <p class="text-gray-600">Spatie Permission, Redis, Excel y más para tu negocio.</p>
                </div>
            </div>
        </div>
    </section>

    <!-- About -->
    <section id="about" class="bg-gray-100 py-16">
        <div class="container mx-auto px-4 text-center">
            <h2 class="text-3xl font-bold mb-4">Sobre Nosotros</h2>
            <p class="text-gray-600 max-w-3xl mx-auto">Koneko es una empresa dedicada a ofrecer soluciones tecnológicas avanzadas, centradas en la eficiencia y la simplicidad para negocios en México. Nuestro objetivo es facilitar tus operaciones.</p>
        </div>
    </section>

    <!-- Contact -->
    <section id="contact" class="py-16">
        <div class="container mx-auto px-4">
            <h2 class="text-3xl font-bold text-center mb-4">Contáctanos</h2>
            <p class="text-gray-600 text-center mb-8">¿Tienes preguntas o necesitas más información? Estamos aquí para ayudarte.</p>
            <div class="max-w-lg mx-auto bg-white shadow p-6 rounded">
                <form action="#" method="POST">
                    <div class="mb-4">
                        <label for="name" class="block text-gray-600">Nombre</label>
                        <input type="text" id="name" name="name" class="w-full">
                    </div>
                    <div class="mb-4">
                        <label for="email" class="block text-gray-600">Correo Electrónico</label>
                        <input type="email" id="email" name="email" class="w-full">
                    </div>
                    <div class="mb-4">
                        <label for="message" class="block text-gray-600">Mensaje</label>
                        <textarea id="message" name="message" rows="4" class="w-full"></textarea>
                    </div>
                    <button type="submit" class="w-full bg-blue-600 text-white py-2 rounded hover:bg-blue-500">Enviar</button>
                </form>
            </div>
        </div>
    </section>

    <!-- Footer -->
    <footer class="bg-blue-600 text-white py-6">
        <div class="container mx-auto text-center">
            <p>&copy; 2025 Koneko Soluciones Tecnológicas. Todos los derechos reservados.</p>
        </div>
    </footer>

    <script>
        const menuBtn = document.getElementById('menu-btn');
        const menu = document.getElementById('menu');

        menuBtn.addEventListener('click', () => {
            menu.classList.toggle('hidden');
        });
    </script>
</body>
</html>
